==> haskell-lsp0-test-0.11.0.7-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp0-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.11.0.7
visibility:           public
id:                   lsp-test-0.11.0.7-1JjkXvU17Yi7AoMHQ0kwYH
key:                  lsp-test-0.11.0.7-1JjkXvU17Yi7AoMHQ0kwYH
license:              BSD-3-Clause
copyright:            2020 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:             https://github.com/bubba/lsp-test#readme
synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.Haskell.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire, and @Language.Haskell.LSP.Test@ can replay captured sessions from
    <haskell-lsp https://hackage.haskell.org/package/haskell-lsp>.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  8eb60f34a9f4279db77d45f3b4b7ab48
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-DiU4leLN1bk4yjPVc8BdOd:Control.Applicative.Combinators,
    Language.Haskell.LSP.Test, Language.Haskell.LSP.Test.Replay,
    Language.Haskell.LSP.Types from haskell-lsp-types-0.24.0.0-Cd07Xm5jqGUKDQ99yskbJd:Language.Haskell.LSP.Types,
    Language.Haskell.LSP.Types.Capabilities from haskell-lsp-types-0.24.0.0-Cd07Xm5jqGUKDQ99yskbJd:Language.Haskell.LSP.Types.Capabilities

hidden-modules:
    Language.Haskell.LSP.Test.Compat Language.Haskell.LSP.Test.Decoding
    Language.Haskell.LSP.Test.Exceptions
    Language.Haskell.LSP.Test.Files Language.Haskell.LSP.Test.Messages
    Language.Haskell.LSP.Test.Parsing Language.Haskell.LSP.Test.Server
    Language.Haskell.LSP.Test.Session

import-dirs:          /usr/lib/ghc-8.10.4/site-local/lsp-test-0.11.0.7
library-dirs:         /usr/lib/ghc-8.10.4/site-local/lsp-test-0.11.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/lsp-test-0.11.0.7
hs-libraries:         HSlsp-test-0.11.0.7-1JjkXvU17Yi7AoMHQ0kwYH
depends:
    Diff-0.4.0-KyPtUOKlpskC2b7jcuQ1e4
    Glob-0.10.1-1sFcmiTBT9m6UCoVw5tPyD
    aeson-1.5.6.0-4fHNEU34DqGLin6g6nejhx
    aeson-pretty-0.8.8-8Edy8u8g9SQHvHRb3INAfR
    ansi-terminal-0.11-ChZQ4tet9RpCZKLIWEgagm
    async-2.2.3-bRJqoep3gj749cy8sss28 base-4.14.1.0
    bytestring-0.10.12.0 conduit-1.3.4.1-D7tjG3uoOloKYIrANBNmms
    conduit-parse-0.2.1.0-8yziq5HIohe9cgVxIGC7qR containers-0.6.2.1
    data-default-0.7.1.1-DVZWGRf90hqGebpGTaPvOV directory-1.3.6.0
    filepath-1.4.2.1 haskell-lsp-0.24.0.0-AddMhFdYjzDLMTGjX9Hcqk
    lens-5.0.1-53WS5NNHoCX50cMN2bRTHU mtl-2.2.2
    parser-combinators-1.3.0-DiU4leLN1bk4yjPVc8BdOd process-1.6.9.0
    text-1.2.4.1 transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.13.0-L0eBZW05rpSJOXS7yU5DxX

haddock-interfaces:   /usr/share/doc/haskell-lsp0-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp0-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp0-test-0.11.0.7-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp0-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.11.0.7
visibility:           public
id:                   lsp-test-0.11.0.7-DWJQ29hbBAk9aNRkQinjFS
key:                  lsp-test-0.11.0.7-DWJQ29hbBAk9aNRkQinjFS
license:              BSD-3-Clause
copyright:            2020 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:             https://github.com/bubba/lsp-test#readme
synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.Haskell.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire, and @Language.Haskell.LSP.Test@ can replay captured sessions from
    <haskell-lsp https://hackage.haskell.org/package/haskell-lsp>.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  1faa0009d0cd18d7c8cc5eac0425cb37
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-DiU4leLN1bk4yjPVc8BdOd:Control.Applicative.Combinators,
    Language.Haskell.LSP.Test, Language.Haskell.LSP.Test.Replay,
    Language.Haskell.LSP.Types from haskell-lsp-types-0.24.0.0-BrTBGVp5Q3dDIym9dgw5tF:Language.Haskell.LSP.Types,
    Language.Haskell.LSP.Types.Capabilities from haskell-lsp-types-0.24.0.0-BrTBGVp5Q3dDIym9dgw5tF:Language.Haskell.LSP.Types.Capabilities

hidden-modules:
    Language.Haskell.LSP.Test.Compat Language.Haskell.LSP.Test.Decoding
    Language.Haskell.LSP.Test.Exceptions
    Language.Haskell.LSP.Test.Files Language.Haskell.LSP.Test.Messages
    Language.Haskell.LSP.Test.Parsing Language.Haskell.LSP.Test.Server
    Language.Haskell.LSP.Test.Session

import-dirs:          /usr/lib/ghc-8.10.4/site-local/lsp-test-0.11.0.7
library-dirs:         /usr/lib/ghc-8.10.4/site-local/lsp-test-0.11.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/lsp-test-0.11.0.7
hs-libraries:         HSlsp-test-0.11.0.7-DWJQ29hbBAk9aNRkQinjFS
depends:
    Diff-0.4.0-KyPtUOKlpskC2b7jcuQ1e4
    Glob-0.10.1-1sFcmiTBT9m6UCoVw5tPyD
    aeson-1.5.6.0-4fHNEU34DqGLin6g6nejhx
    aeson-pretty-0.8.8-8Edy8u8g9SQHvHRb3INAfR
    ansi-terminal-0.11-ChZQ4tet9RpCZKLIWEgagm
    async-2.2.3-bRJqoep3gj749cy8sss28 base-4.14.1.0
    bytestring-0.10.12.0 conduit-1.3.4.1-D7tjG3uoOloKYIrANBNmms
    conduit-parse-0.2.1.0-8yziq5HIohe9cgVxIGC7qR containers-0.6.2.1
    data-default-0.7.1.1-DVZWGRf90hqGebpGTaPvOV directory-1.3.6.0
    filepath-1.4.2.1 haskell-lsp-0.24.0.0-F1dUnl0J0TJ3QBxyzJHc2Q
    lens-5.0.1-ATHEqBmukxhJ8u4w26kFOx mtl-2.2.2
    parser-combinators-1.3.0-DiU4leLN1bk4yjPVc8BdOd process-1.6.9.0
    text-1.2.4.1 transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.13.0-L0eBZW05rpSJOXS7yU5DxX

haddock-interfaces:   /usr/share/doc/haskell-lsp0-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp0-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
